# expand-fab
ExpandFab control for Flet

## Installation

Add dependency to `pyproject.toml` of your Flet app:

* **Git dependency**

Link to git repository:

```
dependencies = [
  "expand-fab @ git+https://github.com/MyGithubAccount/expand-fab",
  "flet>=0.80.1",
]
```

* **uv/pip dependency**  

If the package is published on pypi.org:

```
dependencies = [
  "expand-fab",
  "flet>=0.80.1",
]
```

Build your app:
```
flet build macos -v
```

## Documentation

[Link to documentation](https://MyGithubAccount.github.io/expand-fab/)
